

set -ex



djpeg -dct int -ppm -outfile testout.ppm testorig.jpg
test -f ${PREFIX}/lib/pkgconfig/libjpeg.pc
test -f ${PREFIX}/lib/libjpeg.so
test -f ${PREFIX}/lib/libjpeg.so.9
test -f ${PREFIX}/lib/libjpeg.so.9.5.0
test -f ${PREFIX}/include/jpeglib.h
exit 0
